Reference | Specwright
Description: AI-native enterprise documentation platform. Living specs, agent-maintained docs, repo-native knowledge.

Skip to content

# Reference ​

Detailed reference documentation for Specwright's interfaces and formats.

## Tools & Interfaces ​

- CLI — Command-line interface reference
- MCP Tools — MCP server tools for coding agents
- Claude Code Skills — Specwright plugin commands for Claude Code
- REST API — HTTP API endpoints

## Formats & Schemas ​

- Spec Format — Markdown spec file format specification
- SPECWRIGHT.yaml — Configuration file schema reference